package com.censoft.censoftrongtong.service.impl;

import com.censoft.censoftrongtong.domain.*;
import com.censoft.censoftrongtong.domain.dto.RiskPlanAppApproveDto;
import com.censoft.censoftrongtong.domain.dto.RiskPlanAppDetailsDto;
import com.censoft.censoftrongtong.domain.dto.RiskPlanAppListDto;
import com.censoft.censoftrongtong.domain.dto.RiskPlanAppTaskDetailsDto;
import com.censoft.censoftrongtong.domain.vo.RiskPlanExportVO;
import com.censoft.censoftrongtong.domain.vo.RiskTypeExportVO;
import com.censoft.censoftrongtong.enums.RiskPlanStatusType;
import com.censoft.censoftrongtong.mapper.RiskPlanMapper;
import com.censoft.censoftrongtong.service.*;
import com.github.yulichang.base.MPJBaseServiceImpl;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.core.domain.model.LoginUser;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.BacklogInfo;
import com.ruoyi.system.mapper.BacklogInfoMapper;
import com.ruoyi.system.mapper.SysDeptMapper;
import com.ruoyi.system.service.ISysUserService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.*;
import java.util.concurrent.atomic.AtomicBoolean;
import java.util.stream.Collectors;
import java.util.stream.Stream;

/**
 * 风险计划Service业务层处理
 *
 * @author ruoyi
 * @date 2023-06-26
 */
@Service
public class RiskPlanServiceImpl extends MPJBaseServiceImpl<RiskPlanMapper, RiskPlan> implements IRiskPlanService {
    @Resource
    private RiskPlanMapper riskPlanMapper;

    @Resource
    private IRiskPlanTaskService riskPlanTaskService;

    @Resource
    private ILedgerBuildingService ledgerBuildingService;

    @Resource
    private IRiskPlanUserBuildingService riskPlanUserBuildingService;

    @Resource
    private IRiskPlanInherentListService riskPlanInherentListService;

    @Resource
    private ILedgerProjectService ledgerProjectService;
    @Resource
    private SysDeptMapper sysDeptMapper;

    @Resource
    private ISysUserService userService;

    @Resource
    private ICommonMessageInfoService commonMessageInfoService;

    @Resource
    private BacklogInfoMapper backlogInfoMapper;

    /**
     * 查询风险计划
     *
     * @param id 风险计划主键
     * @return 风险计划
     */
    @Override
    public RiskPlan selectRiskPlanById(Long id) {
        return riskPlanMapper.selectRiskPlanById(id);
    }

    /**
     * 查询风险计划列表
     *
     * @param riskPlan 风险计划
     * @return 风险计划
     */
    @Override
    public List<RiskPlanAppTaskDetailsDto> selectRiskPlanList(RiskPlan riskPlan) {
        return riskPlanMapper.selectRiskPlanList(riskPlan);
    }

    /**
     * 新增风险计划
     *
     * @param riskPlan 风险计划
     * @return 结果
     */
    @Override
    public int insertRiskPlan(RiskPlan riskPlan) {
        riskPlan.setCreateTime(DateUtils.getNowDate());
        return riskPlanMapper.insertRiskPlan(riskPlan);
    }

    /**
     * 修改风险计划
     *
     * @param riskPlan 风险计划
     * @return 结果
     */
    @Override
    public int updateRiskPlan(RiskPlan riskPlan) {
        riskPlan.setUpdateTime(DateUtils.getNowDate());
        return riskPlanMapper.updateRiskPlan(riskPlan);
    }

    /**
     * 批量删除风险计划
     *
     * @param ids 需要删除的风险计划主键
     * @return 结果
     */
    @Override
    public int deleteRiskPlanByIds(Long[] ids) {
        return riskPlanMapper.deleteRiskPlanByIds(ids);
    }

    /**
     * 删除风险计划信息
     *
     * @param id 风险计划主键
     * @return 结果
     */
    @Override
    public int deleteRiskPlanById(Long id) {
        return riskPlanMapper.deleteRiskPlanById(id);
    }

    @Override
    public int saveRiskPlan(RiskPlan riskPlan) {
        //插入主表
        riskPlan.setNo(getNo());
        riskPlan.setStatus(RiskPlanStatusType.WAIT_START.getStatus());
        int i = insertRiskPlan(riskPlan);

        //插入任务表 已完成任务发起
        RiskPlanTask riskPlanTask = new RiskPlanTask();
        riskPlanTask.setPlanId(riskPlan.getId());
        riskPlanTask.setApprovalUserId(riskPlan.getCreateUserId());
        riskPlanTask.setTaskKey(RiskPlanStatusType.CREATE_TASK.getStatus());
        riskPlanTask.setTaskName(RiskPlanStatusType.CREATE_TASK.getTitle());
        riskPlanTask.setStatus("completed");
        riskPlanTask.setStartTime(new Date());
        riskPlanTask.setCompletedTime(new Date());
        riskPlanTaskService.insertRiskPlanTask(riskPlanTask);

        //插入任务表 待执行风险评估
        RiskPlanTask riskPlanTask1 = new RiskPlanTask();
        riskPlanTask1.setPlanId(riskPlan.getId());
        riskPlanTask1.setApprovalUserId(riskPlan.getLeaderUserId());
        riskPlanTask1.setTaskKey(RiskPlanStatusType.WAIT_START.getStatus());
        riskPlanTask1.setTaskName(RiskPlanStatusType.WAIT_START.getTitle());
        riskPlanTask1.setStatus("running");
        riskPlanTask1.setStartTime(new Date());
        riskPlanTaskService.insertRiskPlanTask(riskPlanTask1);

        //插入计划人员与楼宇关系表
        List<RiskPlanUserBuilding> list = Arrays.stream(riskPlan.getBuildingIds().split(",")).map(buildingId -> {
            RiskPlanUserBuilding riskPlanUserBuilding = new RiskPlanUserBuilding();
            riskPlanUserBuilding.setPlanId(riskPlan.getId());
            riskPlanUserBuilding.setBuildingId(Long.valueOf(buildingId));
            riskPlanUserBuilding.setUserIds(riskPlan.getWorkUserIds());
            riskPlanUserBuilding.setStartTime(new Date());
            riskPlanUserBuilding.setStatus("wait");
            return riskPlanUserBuilding;
        }).collect(Collectors.toList());
        riskPlanUserBuildingService.saveBatch(list);

        //更新项目业态信息
        LedgerProject ledgerProject = new LedgerProject();
        ledgerProject.setId(riskPlan.getProjectId());
        ledgerProject.setBusiness(riskPlan.getProjectBusiness());
        ledgerProject.setBusinessStatus(riskPlan.getBusinessStatus());
        ledgerProject.setPropertyManagement(riskPlan.getPropertyManagement());
        ledgerProjectService.updateLedgerProject(ledgerProject);

        //TODO  创建之后待办推送
        //获取创建人
        SysUser createUser = userService.selectUserById(riskPlan.getCreateUserId());
        //获取负责人
        SysUser leaderUser = userService.selectUserById(riskPlan.getLeaderUserId());
        //获取执行人员
        String[] workUsers = riskPlan.getWorkUserIds().split(",");
        String newUser = String.valueOf(riskPlan.getLeaderUserId());
        //使用Stream.concat连接原始用户数组和新用户，然后转换回数组
        workUsers = Stream.concat(Arrays.stream(workUsers), Stream.of(newUser))
                .toArray(String[]::new);
        //消息内容  XXX创建了一条名为[xxx]的风险评估任务,请尽快处理!
        String content = createUser.getNickName() + "创建了一条名为【" + riskPlan.getName() + "】的风险评估任务，请尽快处理！";

        for (int j = 0; j < workUsers.length; j++) {
            SysUser workUser = userService.selectUserById(Long.valueOf(workUsers[j]));

            System.out.println("pid-->"+ riskPlan.getId() + ",manid-->" +riskPlan.getId() + ",backlog_by--?" + workUser.getUserName()
                    + ",create_by-->" + createUser.getUserName()
            );

            commonMessageInfoService.insertBacklogInfo(String.valueOf(riskPlan.getId()), "risk_confirm_sub", String.valueOf(riskPlan.getId()),
                    "风险评估", "风险",
                    content, "0", workUser.getUserName(),
                    "风险评估", "riskTaskList" , "riskTaskList", createUser.getUserName());

            //TODO  消息推送
            commonMessageInfoService.insertMessageInfo(String.valueOf(riskPlan.getId()) + "", "risk_confirm_sub", "风险评估"
                    , content
                    , "0", workUser.getUserName(), "风险评估", "", "riskTaskList", createUser.getUserName());
        }

        return i;
    }

    @Override
    public List<RiskPlanAppListDto> getRiskPlanAppListDtoList(List<RiskPlanStatusType> statusList, Long createUserId
            , Long leaderUserId, Long workUserId,String name) {
        List<String> statusStringList = null;
        //枚举类转化为数据库存的状态值
        if (statusList != null) {
            statusStringList = statusList.stream()
                    .map(RiskPlanStatusType::getStatus)
                    .collect(Collectors.toList());
        }

        //查询并把状态值转化为状态名称
        return riskPlanMapper.getRiskPlanAppListDtoList(statusStringList, createUserId, leaderUserId, workUserId,name)
                .stream()
                .map(dto -> {
                    String status = RiskPlanStatusType.getTitleByStatus(dto.getStatus()).getTitle();
                    dto.setStatus(status);
                    return dto;
                }).collect(Collectors.toList());
    }

    @Override
    public RiskPlanAppDetailsDto getRiskPlanAppDetailsDtoByPlanId(Long planId,Long buildingId) {
        //获取任务单基础信息
        RiskPlanAppDetailsDto dto = riskPlanMapper.getRiskPlanAppDetailsDtoByPlanId(planId);
        dto.setStatus(RiskPlanStatusType.getTitleByStatus(dto.getStatusKey()).getTitle());

        //获取任务详情
        dto.setDetailsDto(riskPlanMapper.getRiskPlanAppTaskDetailsDtoByPlanId(planId));
        if (buildingId != null) {
            LedgerBuilding ledgerBuilding = ledgerBuildingService.selectLedgerBuildingById(buildingId);
            dto.getDetailsDto().setBuildingIds(buildingId+"");
            dto.getDetailsDto().setBuildingNames(ledgerBuilding.getName());
        }

        //风险清单
        dto.setInherentListDtos(riskPlanInherentListService.getInherentListByPlanId(null, buildingId, null, null));

        //风险清单
        dto.setRiskBuildingListDtos(riskPlanMapper.getRiskBuildingListDtoByPlanId(planId,buildingId));

        //审批记录
        dto.setApproveListDtos(riskPlanMapper.getApproveListDtoByPlanId(planId));

        //风险评估报告
        dto.setFiles(new ArrayList());

        return dto;
    }

    @Override
    public List<LedgerBuilding> getBuildingListByPlanId(Long planId) {
        RiskPlan riskPlan = selectRiskPlanById(planId);
        return ledgerBuildingService.getBuildingListByIds(Arrays.asList(riskPlan.getBuildingIds().split(",")));
    }

    @Override
    public int approveAppApproveDto(RiskPlanAppApproveDto appApproveDto) {

        //获取最新的task
        RiskPlanTask lastRiskPlanTask = riskPlanTaskService.getLastRiskPlanTaskByPlanId(appApproveDto.getId());
        lastRiskPlanTask.setTaskResult(appApproveDto.getTaskResult());
        lastRiskPlanTask.setTaskOpinion(appApproveDto.getTaskOpinion());
        lastRiskPlanTask.setStatus("completed");
        lastRiskPlanTask.setCompletedTime(new Date());
        riskPlanTaskService.updateRiskPlanTask(lastRiskPlanTask);

        //计划
        RiskPlan riskPlan = selectRiskPlanById(lastRiskPlanTask.getPlanId());

        if ("0".equals(appApproveDto.getTaskResult())) {

            //组长退回
            if (riskPlan.getStatus().equals(RiskPlanStatusType.WAIT_LEADER_APPROVE.getStatus())
                    ||riskPlan.getStatus().equals(RiskPlanStatusType.WAIT_LEADER_RETURN.getStatus())){
                //如果是组长审批 同时退回修改 楼宇单子的状态
                riskPlanUserBuildingService.updateByRiskPlanAppApproveBuildingDto(appApproveDto.getId(),appApproveDto.getUserId()
                        ,appApproveDto.getBuildingDtos());

                //插入任务表 已退回组员 风险评估
                RiskPlanTask riskPlanTask1 = new RiskPlanTask();
                riskPlanTask1.setPlanId(lastRiskPlanTask.getPlanId());
                riskPlanTask1.setTaskKey(RiskPlanStatusType.WAIT_RETURN.getStatus());
                riskPlanTask1.setTaskName(RiskPlanStatusType.WAIT_RETURN.getTitle());
                riskPlanTask1.setStatus("running");
                riskPlanTask1.setStartTime(new Date());
                riskPlanTask1.setApprovalUserId(appApproveDto.getUserId());
                riskPlanTaskService.insertRiskPlanTask(riskPlanTask1);

                //修改计划状态
                riskPlan.setStatus(RiskPlanStatusType.WAIT_RETURN.getStatus());
                updateRiskPlan(riskPlan);

            }else if(riskPlan.getStatus().equals(RiskPlanStatusType.WAIT_APPROVE.getStatus())){

                //插入任务表 已退回组长 风险评估
                RiskPlanTask riskPlanTask1 = new RiskPlanTask();
                riskPlanTask1.setPlanId(lastRiskPlanTask.getPlanId());
                riskPlanTask1.setApprovalUserId(riskPlan.getLeaderUserId());
                riskPlanTask1.setTaskKey(RiskPlanStatusType.WAIT_LEADER_RETURN.getStatus());
                riskPlanTask1.setTaskName(RiskPlanStatusType.WAIT_LEADER_RETURN.getTitle());
                riskPlanTask1.setStatus("running");
                riskPlanTask1.setStartTime(new Date());
                riskPlanTaskService.insertRiskPlanTask(riskPlanTask1);

                //修改计划状态
                riskPlan.setStatus(RiskPlanStatusType.WAIT_LEADER_RETURN.getStatus());
                updateRiskPlan(riskPlan);
            }
        } else {
            if (riskPlan.getStatus().equals(RiskPlanStatusType.WAIT_LEADER_APPROVE.getStatus())
                    || riskPlan.getStatus().equals(RiskPlanStatusType.WAIT_LEADER_RETURN.getStatus())){
                //修改计划状态
                riskPlan.setStatus(RiskPlanStatusType.WAIT_APPROVE.getStatus());
                updateRiskPlan(riskPlan);

                //插入任务表 审批任务
                RiskPlanTask riskPlanTask1 = new RiskPlanTask();
                riskPlanTask1.setPlanId(lastRiskPlanTask.getPlanId());
                riskPlanTask1.setApprovalUserId(riskPlan.getApproveUserId());
                riskPlanTask1.setTaskKey(RiskPlanStatusType.WAIT_APPROVE.getStatus());
                riskPlanTask1.setTaskName(RiskPlanStatusType.WAIT_APPROVE.getTitle());
                riskPlanTask1.setStatus("running");
                riskPlanTask1.setStartTime(new Date());
                riskPlanTaskService.insertRiskPlanTask(riskPlanTask1);

                //TODO  执行结束后 将该评估的待办变更为已读
                //获取当前风险评估的ID 的待办信息
                BacklogInfo backlogInfo = new BacklogInfo();
                backlogInfo.setPid(String.valueOf(riskPlan.getId()));
                backlogInfo.setStatus("0");
                List<BacklogInfo> backlogInfos = backlogInfoMapper.selectBacklogInfoList(backlogInfo);
                for (int i = 0; i < backlogInfos.size(); i++) {
                    BacklogInfo backlogInfo1 = new BacklogInfo();
                    backlogInfo1.setPid(String.valueOf(riskPlan.getId()));
                    backlogInfo1.setStatus("1");
                    int i1 = backlogInfoMapper.updateBacklogInfoByPid(backlogInfo1);
                }

                //TODO  审批阶段待办推送
                //获取当前人员
                LoginUser user = SecurityUtils.getLoginUser();
                SysUser loginUser = userService.selectUserById(user.getUserId());
                //获取创建人
                SysUser createUser = userService.selectUserById(riskPlan.getCreateUserId());
                //获取负责人
                SysUser leaderUser = userService.selectUserById(riskPlan.getLeaderUserId());
                //消息内容  XXX给您发送一条名为[xxx]的风险评估审批,请尽快处理!
                String content = loginUser.getNickName() + "给您发送了一条名为【" + riskPlan.getName() + "】的风险评估审批，请尽快处理！";

                System.out.println("pid-->"+ riskPlan.getId() + ",manid-->" +riskPlan.getId() + ",backlog_by--?" + createUser.getUserName()
                        + ",create_by-->" + loginUser.getNickName() + "content-->" + content
                );

                commonMessageInfoService.insertBacklogInfo(String.valueOf(riskPlan.getId()), "risk_confirm_sub", String.valueOf(riskPlan.getId()),
                        "风险审批", "风险",
                        content, "0", createUser.getUserName(),
                        "风险审批", "riskTaskList" , "riskTaskList", loginUser.getUserName());

                //TODO  审批阶段消息推送
                commonMessageInfoService.insertMessageInfo(String.valueOf(riskPlan.getId()) + "", "risk_confirm_sub", "风险评估"
                        , content
                        , "0", createUser.getUserName(), "风险评估", "", "riskTaskList",
                        loginUser.getUserName());



            }else {
                //修改计划状态
                riskPlan.setStatus(RiskPlanStatusType.FINISH.getStatus());
                updateRiskPlan(riskPlan);

                //插入任务表 项目评估报告
                RiskPlanTask riskPlanTask1 = new RiskPlanTask();
                riskPlanTask1.setPlanId(lastRiskPlanTask.getPlanId());
                riskPlanTask1.setTaskKey(RiskPlanStatusType.PROJECT_REPORT.getStatus());
                riskPlanTask1.setTaskName(RiskPlanStatusType.PROJECT_REPORT.getTitle());
                riskPlanTask1.setStatus("completed");
                riskPlanTask1.setStartTime(new Date());
                riskPlanTask1.setCompletedTime(new Date());
                riskPlanTask1.setApprovalUserId(appApproveDto.getUserId());
                riskPlanTaskService.insertRiskPlanTask(riskPlanTask1);

                //插入任务表 已完成
                RiskPlanTask riskPlanTask2 = new RiskPlanTask();
                riskPlanTask2.setPlanId(lastRiskPlanTask.getPlanId());
                riskPlanTask2.setTaskKey(RiskPlanStatusType.FINISH.getStatus());
                riskPlanTask2.setTaskName(RiskPlanStatusType.FINISH.getTitle());
                riskPlanTask2.setStatus("completed");
                riskPlanTask2.setStartTime(new Date());
                riskPlanTask2.setCompletedTime(new Date());
                riskPlanTask2.setApprovalUserId(appApproveDto.getUserId());
                riskPlanTaskService.insertRiskPlanTask(riskPlanTask2);

                //TODO  执行结束后 将该评估的待办变更为已读
                //获取当前风险评估的ID 的待办信息
                BacklogInfo backlogInfo = new BacklogInfo();
                backlogInfo.setPid(String.valueOf(riskPlan.getId()));
                backlogInfo.setStatus("0");
                List<BacklogInfo> backlogInfos = backlogInfoMapper.selectBacklogInfoList(backlogInfo);
                for (int i = 0; i < backlogInfos.size(); i++) {
                    BacklogInfo backlogInfo1 = new BacklogInfo();
                    backlogInfo1.setPid(String.valueOf(riskPlan.getId()));
                    backlogInfo1.setStatus("1");
                    int i1 = backlogInfoMapper.updateBacklogInfoByPid(backlogInfo1);
                }

                //TODO  审批完成消息推送
                //获取当前人员
                LoginUser user = SecurityUtils.getLoginUser();
                SysUser loginUser = userService.selectUserById(user.getUserId());
                //获取负责人
                SysUser leaderUser = userService.selectUserById(riskPlan.getLeaderUserId());
                //获取执行人员
                String[] workUsers = riskPlan.getWorkUserIds().split(",");
                String newUser = String.valueOf(riskPlan.getLeaderUserId());
                //使用Stream.concat连接原始用户数组和新用户，然后转换回数组
                workUsers = Stream.concat(Arrays.stream(workUsers), Stream.of(newUser))
                        .toArray(String[]::new);
                //消息内容  你参与的名为[xxx]风险评估任务已完成!
                String content = "您参与的名为【" + riskPlan.getName() + "】的风险评估任务已完成！";

                for (int i = 0; i < workUsers.length; i++) {
                    SysUser workUser = userService.selectUserById(Long.valueOf(workUsers[i]));
                    commonMessageInfoService.insertMessageInfo(String.valueOf(riskPlan.getId()) + "", "risk_confirm_sub",
                            "风险评估", content, "0", workUser.getUserName(), "风险评估",
                            "", "riskTaskList", loginUser.getUserName());
                }

            }

        }
        return 1;
    }

    @Override
    public int revokeByPlanId(Long planId, Long userId) {
        //计划
        RiskPlan riskPlan = selectRiskPlanById(planId);

        //获取最新的task
        RiskPlanTask lastRiskPlanTask = riskPlanTaskService.getLastRiskPlanTaskByPlanId(planId);
        lastRiskPlanTask.setStatus("completed");
        lastRiskPlanTask.setCompletedTime(new Date());
        riskPlanTaskService.updateRiskPlanTask(lastRiskPlanTask);

        //插入任务表 已撤销风险评估
        RiskPlanTask riskPlanTask1 = new RiskPlanTask();
        riskPlanTask1.setPlanId(lastRiskPlanTask.getPlanId());
        riskPlanTask1.setTaskKey(RiskPlanStatusType.REVOKE.getStatus());
        riskPlanTask1.setTaskName(RiskPlanStatusType.REVOKE.getTitle());
        riskPlanTask1.setStatus("completed");
        riskPlanTask1.setStartTime(new Date());
        riskPlanTask1.setApprovalUserId(userId);
        riskPlanTaskService.insertRiskPlanTask(riskPlanTask1);

        //修改计划状态
        riskPlan.setStatus(RiskPlanStatusType.REVOKE.getStatus());
        updateRiskPlan(riskPlan);

        return 1;
    }

    @Override
    public List<RiskPlanAppListDto> getRiskPlanAppListDtoListByApproveUser(Long userId,String status,String result) {
        //查询并把状态值转化为状态名称
        return riskPlanMapper.getRiskPlanAppListDtoListByApproveUser(userId,status,result)
                .stream()
                .map(dto -> {
                    String statusName = RiskPlanStatusType.getTitleByStatus(dto.getStatus()).getTitle();
                    dto.setStatus(statusName);
                    return dto;
                }).collect(Collectors.toList());
    }

    @Override
    public List<RiskPlanAppListDto> getRiskPlanAppListDtoListByCreateUserDeptId(Long deptId,String name) {
        return riskPlanMapper.getRiskPlanAppListDtoListByCreateUserDeptId(deptId,name);
    }

    @Override
    public int updateRiskPlanById(RiskPlan riskPlan) {
        //插入主表
        int i = updateRiskPlan(riskPlan);

        //删除历史
        riskPlanUserBuildingService.deleteByPlanId(riskPlan.getId());

        //插入计划人员与楼宇关系表
        List<RiskPlanUserBuilding> list = Arrays.stream(riskPlan.getBuildingIds().split(",")).map(buildingId -> {
            RiskPlanUserBuilding riskPlanUserBuilding = new RiskPlanUserBuilding();
            riskPlanUserBuilding.setPlanId(riskPlan.getId());
            riskPlanUserBuilding.setBuildingId(Long.valueOf(buildingId));
            riskPlanUserBuilding.setUserIds(riskPlan.getWorkUserIds());
            riskPlanUserBuilding.setStartTime(new Date());
            riskPlanUserBuilding.setStatus("wait");
            return riskPlanUserBuilding;
        }).collect(Collectors.toList());
        riskPlanUserBuildingService.saveBatch(list);

        return i;
    }

    private String getNo() {
        Random random = new Random();
        int randomNumber = random.nextInt(1000); // 生成0到999之间的随机数
        String formattedNumber = String.format("%03d", randomNumber); // 格式化为三位数，不足三位前面补0
        return DateUtils.dateTimeNow() + formattedNumber;
    }

    @Override
    public RiskPlanExportVO riskPlanExport(Long id) {
        //查询计划详情
        RiskPlan riskPlan = selectRiskPlanById(id);
        //初始化响应对象
        RiskPlanExportVO vo = riskPlanMapper.riskPlanExport(riskPlan);
        vo.setAdvise(riskPlan.getRemark());
        //风险类型
        if(!StringUtils.isEmpty(vo.getZjdInherentType())){
            //重大 较大风险类型
            Set<String> zjdInherentTypeSet = new HashSet<>(Arrays.asList(vo.getZjdInherentType().split(",")));
            vo.setZjdInherentType(zjdInherentTypeSet.toString());
            //所有风险的数量
            List<RiskTypeExportVO> riskTypeList = new ArrayList<>();
            for(String inherentType : vo.getInherentType().split(",")){
                AtomicBoolean falg = new AtomicBoolean(false);
                riskTypeList.forEach(riskType ->{
                    if(inherentType.equals(riskType.getRiskTypeName())){
                        riskType.setRiskTypeNum(riskType.getRiskTypeNum()+1);
                        falg.set(true);
                    }
                });
                if(!falg.get()){
                    RiskTypeExportVO riskType = new RiskTypeExportVO();
                    riskType.setRiskTypeName(inherentType);
                    riskType.setRiskTypeNum(1);
                    riskTypeList.add(riskType);
                }
            }
            //风险类型
            Set<String> inherentTypeSet = new HashSet<>(Arrays.asList(vo.getInherentType().split(",")));
            vo.setInherentType(inherentTypeSet.toString());
            vo.setInherentTypeCount(String.valueOf(inherentTypeSet.size()));

            vo.setRiskTypeList(riskTypeList);
        }
        //查询所有的风险
        List<String>  zd = riskPlanMapper.riskPlanRoomName(id,"重大风险");
        List<String>  jd = riskPlanMapper.riskPlanRoomName(id,"较大风险");
        List<String>  yb = riskPlanMapper.riskPlanRoomName(id,"一般风险");
        List<String>  d = riskPlanMapper.riskPlanRoomName(id,"低风险");
        vo.setZd(zd.toString());
        vo.setJd(jd.toString());
        vo.setYb(yb.toString());
        vo.setD(d.toString());
        vo.setZdNum(String.valueOf(zd.size()));
        vo.setJdNum(String.valueOf(jd.size()));
        vo.setYbNum(String.valueOf(yb.size()));
        vo.setDNum(String.valueOf(d.size()));
        return vo;
    }
}
